"use strict";

exports.__esModule = true;
exports.unregister = unregister;
exports.register = exports.isLocalhost = void 0;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

var isLocalhost = Boolean(!process.env.NODE_ENV || process.env.NODE_ENV === 'development');
/**
 * @param {{swUrl: string, onUpdate: function, onSuccess: function}} config 
 */

exports.isLocalhost = isLocalhost;

var register = function register(config) {
  if (config === void 0) {
    config = {};
  }

  return new Promise(function (resolve, reject) {
    if ('serviceWorker' in navigator) {
      if (!config.swUrl) {
        config.swUrl = '/service-worker.js';
      } // The URL constructor is available in all browsers that support SW.


      var publicUrl = new URL(process.env.PUBLIC_URL, window.location.href);

      if (publicUrl.origin !== window.location.origin) {
        // Our service worker won't work if PUBLIC_URL is on a different origin
        // from what our page is served on. This might happen if a CDN is used to
        // serve assets; see https://github.com/facebook/create-react-app/issues/2374
        return reject();
      }

      if (isLocalhost) {
        // This is running on localhost. Let's check if a service worker still exists or not.
        checkValidServiceWorker(config).then(function () {
          navigator.serviceWorker.ready.then(function (registration) {
            resolve(registration);
          });
        });
      } else {
        // Is not localhost. Just register service worker
        registerValidSW(config).then(function (e) {
          resolve(e);
        });
      }
    }
  });
};

exports.register = register;

var registerValidSW = /*#__PURE__*/function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee(config) {
    var registration;
    return _regenerator["default"].wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            _context.next = 3;
            return navigator.serviceWorker.register(config.swUrl);

          case 3:
            registration = _context.sent;

            registration.onupdatefound = function () {
              var installingWorker = registration.installing;

              if (installingWorker == null) {
                return false;
              }

              installingWorker.onstatechange = function () {
                if (installingWorker.state === 'installed') {
                  if (navigator.serviceWorker.controller) {
                    // Execute callback
                    // sw will only work if the user closes the tab and opens it again
                    // my sugestion: redirect to a url with loading animation and timeout, then come back here again
                    if (config && config.onUpdate) {
                      config.onUpdate(registration);
                    }
                  } else {
                    // At this point, everything has been precached.
                    // It's the perfect time to display a
                    // "Content is cached for offline use." message.
                    // configure your callback
                    if (config && config.onSuccess) {
                      config.onSuccess(registration);
                    }
                  }
                }
              };

              return registration;
            };

            _context.next = 10;
            break;

          case 7:
            _context.prev = 7;
            _context.t0 = _context["catch"](0);
            if (config && config.onError) config.onError();

          case 10:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, null, [[0, 7]]);
  }));

  return function registerValidSW(_x) {
    return _ref.apply(this, arguments);
  };
}();

var checkValidServiceWorker = /*#__PURE__*/function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee2(config) {
    var response, contentType;
    return _regenerator["default"].wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.prev = 0;
            _context2.next = 3;
            return fetch(config.swUrl, {
              headers: {
                'Service-Worker': 'script'
              }
            });

          case 3:
            response = _context2.sent;
            // Ensure service worker exists, and that we really are getting a JS file.
            contentType = response.headers.get('content-type');

            if (response.status === 404 || contentType != null && contentType.indexOf('javascript') === -1) {
              // No service worker found. Probably a different app. Reload the page.
              navigator.serviceWorker.ready.then(function (registration) {
                registration.unregister().then(function () {
                  window.location.reload();
                  return false;
                });
              });
            } else {
              // Service worker found. Proceed as normal.
              registerValidSW(config).then(function (e) {
                return true;
              });
            }

            ;
            _context2.next = 12;
            break;

          case 9:
            _context2.prev = 9;
            _context2.t0 = _context2["catch"](0);
            // Page is offline.
            if (config && config.onOffline) config.onOffline();

          case 12:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2, null, [[0, 9]]);
  }));

  return function checkValidServiceWorker(_x2) {
    return _ref2.apply(this, arguments);
  };
}();

function unregister() {
  if ('serviceWorker' in navigator) {
    navigator.serviceWorker.ready.then(function (registration) {
      registration.unregister();
    })["catch"](function (error) {
      console.error(error.message);
    });
  }
}